from setuptools import setup
setup(
    name = 'gillu', # while installing pacakge, e.g., matplotlib...
    version = '0.0.1',
    description = 'Simple Bank Account.',
    long_description = open('Readme.txt').read(),
    url = 'https://pypi.org/user/imvickykumar999/',
    author = 'aakash verma',
    keywords = ['account', 'bank', 'class', 'ideationology'],
    packages = ['vicks'], # while importing package, e.g., pyplot...
)
